# Vcore3 500^3
## Intro
Configure and document a [Vcore3 from RatRig](https://www.ratrig.com/3d-printing-cnc/3d-printer-kits/all-3d-printer-kits/v-core3configurable.html) with a Duet 3 6HC. The Vcore3 is a [core xy 3d printer](https://www.reprap.org/wiki/CoreXY) with a kinematic bed on 3 axis.
The purpose of this repo is not to have a 1 fit all solution but the solution that works for my use case, I've tryed to provide all the hardware components and their setup, this may not suit your case. If you have a suggestion please consider opening a pull request. 
In the other hand it may help you setup your printer in a fast way, use at your own risk.
Parts of the g code are not mine and were extracted from the ratrig config, duet github repos, and other sources (references on the links and external sources bellow).

Pay special attention to the stepper direction and stepper step/angle, these are not standard.

## Git structure
### V1 branch 

* Tries to keep compatibility with the default RR HW
* Can be used as a default config

### Master

* It uses my personal config
* It supports or will support newer/better hw, pwm fans, camera, thermal camera, etc
* Better HW monitoring
* Better automation 

## HW Config
#####
- 1x [Duet 3 6HC](https://www.123-3d.nl/Duet3D-Duet-3-Mainboard-6HC-v1-0-origineel-Duet-3-MB6HC-v1-00-i4602.html)

<img src="Duet3-6HC_BoardDiagram.png" alt="Duet3 6HC Diagram" width="1600"/>

##### Display
- 1x [Duet panel Due](https://www.123-3d.nl/Duet3D-PanelDue-met-7-v1-0-display-kabel-PanelDue-7i-v1-0-i3018-t14808.html)

##### SBC
- 1x [PI 4 2GB](https://www.123-3d.nl/RaspberryPi-Raspberry-Pi-4-model-B-2-GB-i4908-t16066.html)

##### Power supply
- 1x Mean well 400W 24v - ([RSP-500-24](https://eu.mouser.com/ProductDetail/MEAN-WELL/RSP-500-24?qs=8uyp%2Fy7yFW5FrdkZCZycgg==))
- 1x Mean well 50w 5v - [LRS-50-5](https://www.meanwell-web.com/en-gb/ac-dc-single-output-enclosed-power-supply-lrs--50--5) 

##### Steppers
- 3x z [0.9 nema 17](https://www.123-3d.nl/123-3D-NEMA17-stappenmotor-0-9-graden-per-stap-48-mm-lang-4-2-kg-cm-SL42S248MA108-0524-i3420-t14804.html) 
- 1x x 1.8 nema 17
- 1x y 1.8 nema 17
- 1x extruder [0.9 nema 17 pancake](https://www.ratrig.com/nema-17-stepper-motor-slimline.html)

Replaced x y 0.9º nema 17 for 1.8º [LDO steppers](https://www.ratrig.com/nema-17-stepper-motor.html), these old 2.5A per phase at 3.1v.
Pay attention to currents and number of steps while configuring your printer.

Note: the stepper except the pancake one have the following specs:
``` 
Draaddikte: 	24 Awg 	Aantal draden: 	4
Nominale stroom: 1,7 A 	Weerstand: 	1,8 Ω
Afmetingen: 	42,3 x 42,3 x 48 mm (LxBxH) 	As diameter: 	5 mm
Voltage: 	3,1 V 	Stap hoek: 	0,9 °
Houdkoppel: 	4.2 kg-cm 	As lengte: 	22 mm
Montagegat: 	M3 
```

##### Carriage
- 1x [Eva 2.0](https://main.eva-3d.page/)

##### HotEnd
- 1x [E3D V6](https://www.123-3d.nl/E3D-v6-hotend-complete-kit-1-75-mm-24V-thermistor-cartridge-origineel-i2184-t13151.html)
- 1x [Bondtech BMG Extruder](https://www.123-3d.nl/Bondtech-BMG-Extruder-EXT-BMG-i3776-t15696.html)

##### Lighting
- 1x [SSR 40A DC-DC](https://www.la3d.ch/e-shop/relais-ssr-creality-3d-cr-10s-pro/)
- 2x [Led strips 24v 50cm](https://www.amazon.nl/gp/product/B07N1GDJV1/ref=ppx_yo_dt_b_asin_title_o03_s00?ie=UTF8&psc=1)
Note: The usage of a second SSR allows more lighting to be added without worries for curruent usage on the board.
 
##### Fans
- 1x [STD ratrig layer fan 24v](https://www.ratrig.com/fan-50mm-blower-type-24v-dc.html)
- 1x [STD ratrig tool fan 24v](https://www.ratrig.com/3d-printing-cnc/3d-printer-kits/accessories/fan-40mm-brushless-24v-dc.html)

##### Bed calibration tool
- 1x [Bltouch 3.1](https://www.123-3d.nl/Antclabs-BLTouch-Auto-Bed-Leveling-Sensor-v3-1-BLTOUCH-i3640-t16885.html)

##### Endstops
- 2x [Ratrig std end stops](https://www.ratrig.com)

##### Bed heater
- 1x [C-Lin SSR](https://www.ratrig.com/hardware2/electronics/clin-ssr-40a-relay.html)
- 1x [Keenovo heating element](https://www.ratrig.com/hardware2/electronics/heater-bed-pad-keenovo-500-x-500mm-220v-1600w.html)

##### Filament sensor
1x [Duet 3d - laser sensor](https://www.123-3d.nl/Duet3D-Laser-Filament-Monitor-LaserFilamentMonitor-i3121-t14808.html)

##### Power automation
1x SONOFF 10A [BASICR2](https://sonoff.tech/product/diy-smart-switch/basicr2/)
 
### Software
#### Base intall
[Duet light](https://pkg.duet3d.com/DuetPi-lite.zip) - Config [link](https://duet3d.dozuki.com/Wiki/SBC_Setup_for_Duet_3)
#### Git config && software deployment
```
apt-get update && apt-get upgrade && apt-get install git
mv /opt/dsf/sd/sys /opt/dsf/sd/sys.ori
mv /opt/dsf/sd/macros /opt/dsf/sd/macros.ori
cd /opt ; git clone https://g.lgeex.com/3dprinting/duet_vcore3.git
chown -R dsf:dsf /opt/duet_vcore3
chmod -R g+s /opt/duet_vcore3 
setfacl -R -d -m u::rwx /opt/duet_vcore3
ln -s /opt/duet_vcore3 /opt/dsf/sd/sys
ln -s /opt/duet_vcore3/macros /opt/dsf/sd/macros
ls -s /opt/duet_vcore3 /root/ # yes I use root on the rasp.
```

### Duet 3 6HC - Pins

#### Accelerometer 
* Temp daughterboard - [LIS3HD](https://www.digikey.nl/en/products/detail/adafruit-industries-llc/3886/10709725) 

#### IO
Used IO pin headers
* io_0 - display
* io_1 - y endstop
* io_2 - x endstop
* io_3 - Duet filament sensor
* io_7 - bltouch

#### Stepper motors

* z left - driver2 - motion backwards (looking from the back of the printer) - 0.9º
* z rear - driver1 - motion backwards - 0.9º
* z right - driver1 - motion backwards - 0.9º
* top right motor - driver3 - Y - motion forwards (looking from the back of the printer) - 1.8º
* top left motor - driver4 - X  - motion forwards - 1.8º
* extruder motor - driver5  - motion forwards - 0.9º

#### Outputs
##### Heating elements (24v)
Heating elements in use:
* out1 - SSR Bed
* out2 - Hotend

##### Fans (24v)
Fans in use:
* out4 - layer fan
* out7 - hotend fan

##### Lighting
* out8 - dc ssr operated leds

#### Temperature probes
Thermal probes in use:
* temp0 - Bed thermistor
* temp1 - Hotend thermistor

#### Jumpers
* Internal 5V - Enable
* 5V -> SBC - Disable
* SBC -> 5V - Disable

The SBC is powerwered by the Mean Well LRS-50-5

#### Emergency Reset 
Emergency reset button is connected to reset pins.

## TODO
- Add printing tracking camera 
- Add accelerometer config

- All macros are untested until stated otherwise (some are cloned from duet repos, others are mine), list of tested macros: 
- - Lighting (all)
- - Preheat (all)
- - PID tuning Bed && HotEnd
- - Preheat PLA / ASA / PETG
- - Musical Tunes
- - Diagnostics/Disallow unhomed moves
- - Diagnostics/E steps calibration

## Electronics backplate
I've also add a electronics backplate (to be a cut of alluminium or polycarbonate up to 4mm), you may find it in [thingiverse.com](https://www.thingiverse.com/thing:4792093).

## Links and external sources
* [GCode library](https://duet3d.dozuki.com/Wiki/Gcode)
* [RatRig vcore3 docs](https://ratrig.dozuki.com/c/Rat_Rig_V-Core_3)
* [Duet Macros repo](https://github.com/Duet3D/GcodeMacros)
* [RatRig Vcore video by TeachingTech](https://www.youtube.com/watch?v=XoTxFs3BGuk&t)
